@@ -2,7 +2,7 @@ import torch
 import pandas as pd
 import numpy as np
 from lightwood.encoder.base import BaseEncoder
-from lightwood.api import dtype
+from type_infer.dtype import dtype
 from lightwood.encoder.helpers import MinMaxNormalizer, CatNormalizer
 from lightwood.helpers.general import is_none
 from typing import List, Iterable
