@@ -2,7 +2,7 @@ from typing import List
 import torch
 from lightwood.encoder import BaseEncoder
 from lightwood.encoder.categorical import CategoricalAutoEncoder
-from lightwood.helpers.text import tokenize_text
+from type_infer.helpers import tokenize_text
 from lightwood.helpers.torch import concat_vectors_and_pad, average_vectors
 import pandas as pd
 
